//
//  AMSDKMediaDeviceManager.h
//  AliMeetingSDK
//
//  Created by xuanzhen.zjw on 2019/8/15.
//  Copyright © 2019 Alibaba. All rights reserved.
//

#import <Foundation/Foundation.h>

#import <AliMeetingSDK/AMSDKMediaDevice.h>

NS_ASSUME_NONNULL_BEGIN

/**
 * 媒体设备变化回调
 */
@protocol AMSDKMediaDeviceChangeCallback <NSObject>

//! 媒体设备发生变化 isAdded：YES-增加设备; NO-删除设备
- (void)onMediaDeviceChanged:(BOOL)isAdded device:(AMSDKMediaDevice *)device;

//! 视频输入设备变化回调，如切换摄像头
- (void)onVideoInputDeviceChanged:(AMSDKMediaDevice *)device;

//! 音频输出设备变化回调，如连接耳机、蓝牙设备等
- (void)onAudioOutputDeviceChanged:(AMSDKMediaDevice *)device;

@end

/**
 * 媒体设备管理类
 */
@interface AMSDKMediaDeviceManager : NSObject

//! 代理，见@AMSDKMediaDeviceChangeCallback
@property (nonatomic, weak) id<AMSDKMediaDeviceChangeCallback> delegate;

//! 扬声器是否开启
@property (nonatomic, assign, readonly) BOOL isSpeakerEnabled;

//! 根据摄像头 Index 切换摄像头，参数见@AMSDKCameraDeviceFacing
- (void)switchCamera:(AMSDKCameraDeviceFacing)facing;

//! 根据摄像头 Index 自动切换摄像头
- (void)switchCamera;

//! 启动/关闭扬声器
- (void)enableSpeaker:(BOOL)enabled;

//! 启动/关闭近距离传感器
- (void)enableProximitySensor:(BOOL)enabled;

#pragma mark - 以下接口iOS端不可用

/**
 * 强制改变音频输出到目标设备
 * @param device 目标设备
 */
- (void)changeAudioOutputDevice:(AMSDKMediaDevice *)device NS_UNAVAILABLE;

/**
 * 强制改变音频输入设备为目标设备
 * @param device 目标设备
 */
- (void)changeAudioInputDevice:(AMSDKMediaDevice *)device NS_UNAVAILABLE;

/**
 * 获取当前CameraDevice
 * iOS不可用
 */
- (AMSDKMediaDevice *)getCameraDevice NS_UNAVAILABLE;

/**
 * 播放文件
 * iOS不可用
 */
- (void)startPlayPath:(NSString *)filePath NS_UNAVAILABLE;

/**
 * 获取设备列表
 * iOS不可用
 */
- (NSArray<AMSDKMediaDevice *> *)getExistDeviceList NS_UNAVAILABLE;

#pragma mark - 注意：下列初始化方法不可用

+ (instancetype)new NS_UNAVAILABLE;

- (instancetype)init NS_UNAVAILABLE;

@end

NS_ASSUME_NONNULL_END
